# Project Template for BHKLab Projects

![Conda Version](https://img.shields.io/conda/v/conda-forge/bhklab-project-template)
![GitHub Release](https://img.shields.io/github/v/release/bhklab/bhklab-project-template)
![PyPI - Version](https://img.shields.io/pypi/v/bhklab-project-template)

![Conda Downloads](https://img.shields.io/conda/d/conda-forge/bhklab-project-template)
![PyPI - Downloads](https://img.shields.io/pypi/dm/bhklab-project-template)

Checkout the [documentation](https://bhklab.github.io/bhklab-project-template/) for more information.
